@@ -592,7 +592,7 @@ class _Parser(barectf_config_parse_common._Parser):
                                         clk_type_uuid, clk_type_node.get('description'),
                                         clk_type_node.get('precision', 0),
                                         barectf_config.ClockTypeOffset(offset_seconds, offset_cycles),
-                                        clk_type_node.get('origin-is-unix-epoch', False))
+                                        clk_type_node.get('origin-is-unix-epoch', True))
 
     def _create_clk_types(self):
         self._clk_types = {}
@@ -657,8 +657,12 @@ class _Parser(barectf_config_parse_common._Parser):
                 dsts.add(self._create_dst(dst_name, dst_node))
 
             # create trace type
-            return barectf_config.TraceType(self._native_byte_order, dsts, trace_type_uuid,
-                                            features)
+            if self._trace_byte_order_prop_key == 'native-byte-order':
+                trace_type_cls = barectf_config.TraceType
+            else:
+                trace_type_cls = barectf_config.TraceTypeWithUnknownNativeByteOrder
+
+            return trace_type_cls(self._trace_byte_order, dsts, trace_type_uuid, features)
         except _ConfigurationParseError as exc:
             _append_error_ctx(exc, 'Trace type')
 
@@ -1091,6 +1095,12 @@ class _Parser(barectf_config_parse_common._Parser):
     def _trace_type_props(self) -> Iterable[Tuple[Any, str]]:
         yield from _Parser._props(self.config_node['trace']['type'])
 
+    def _set_trace_byte_order_prop_key(self):
+        if 'native-byte-order' in self._trace_type_node:
+            self._trace_byte_order_prop_key = 'native-byte-order'
+        else:
+            self._trace_byte_order_prop_key = 'trace-byte-order'
+
     # Normalize the properties of the configuration node.
     #
     # This method, for each property of the trace type node:
@@ -1099,8 +1109,7 @@ class _Parser(barectf_config_parse_common._Parser):
     #
     # 2. Chooses a specific `class` property value.
     #
-    # 3. Chooses a specific `byte-order`/`native-byte-order` property
-    #    value.
+    # 3. Chooses a specific trace byte order property value.
     #
     # 4. Chooses a specific `preferred-display-base` property value.
     #
@@ -1116,7 +1125,7 @@ class _Parser(barectf_config_parse_common._Parser):
                 parent_node[key] = 'little-endian'
 
         trace_node = self.config_node['trace']
-        normalize_byte_order_prop(self._trace_type_node, 'native-byte-order')
+        normalize_byte_order_prop(self._trace_type_node, self._trace_byte_order_prop_key)
 
         for parent_node, key in self._trace_type_props():
             node = parent_node[key]
@@ -1159,10 +1168,10 @@ class _Parser(barectf_config_parse_common._Parser):
             if node is None:
                 del trace_node[prop_name]
 
-    # Sets the parser's native byte order.
-    def _set_native_byte_order(self):
-        self._native_byte_order_node = self._trace_type_node['native-byte-order']
-        self._native_byte_order = self._byte_order_from_node(self._native_byte_order_node)
+    # Sets the parser's trace byte order.
+    def _set_trace_byte_order(self):
+        self._trace_byte_order_node = self._trace_type_node[self._trace_byte_order_prop_key]
+        self._trace_byte_order = self._byte_order_from_node(self._trace_byte_order_node)
 
     # Processes the inclusions of the event record type node
     # `ert_node`, returning the effective node.
@@ -1322,6 +1331,9 @@ class _Parser(barectf_config_parse_common._Parser):
         # effective configuration node.
         self._schema_validator.validate(self.config_node, 'config/3/config')
 
+        # Set the trace byte order property key.
+        self._set_trace_byte_order_prop_key()
+
         # Normalize properties.
         #
         # This process removes `None` properties and chooses specific
@@ -1336,8 +1348,8 @@ class _Parser(barectf_config_parse_common._Parser):
         # doesn't need to check for `None` nodes or enumerator aliases.
         self._normalize_props()
 
-        # Set the native byte order.
-        self._set_native_byte_order()
+        # Set the trace byte order.
+        self._set_trace_byte_order()
 
         # Create a barectf configuration object from the configuration
         # node.
